import * as i0 from '@angular/core';
import { Directive, HostListener, Component, ViewEncapsulation, ViewChild, Input, NgModule } from '@angular/core';
import { Datepicker } from 'vanillajs-datepicker';
import * as i1 from '@angular/forms';
import { NG_VALUE_ACCESSOR, NG_VALIDATORS, ReactiveFormsModule, FormsModule } from '@angular/forms';
import { DateTime, Settings } from 'luxon';
import { createAutoCorrectedDatePipe } from 'text-mask-addons';
import * as i2 from 'angular2-text-mask';
import { TextMaskModule } from 'angular2-text-mask';
import { CommonModule } from '@angular/common';

class DateHelper {
    static isoDateStringToJSDate(isoDate) {
        if (!isoDate) {
            return DateTime.invalid('Invalid date').toJSDate();
        }
        return DateTime.fromISO(isoDate).toJSDate();
    }
    static isoDateStringToFormattedDate(isoDate, format) {
        return DateTime.fromISO(isoDate).toFormat(format || 'dd/MM/yyyy');
    }
    static jsDateToFormattedDate(date, format) {
        return DateTime.fromJSDate(date)
            .setZone('Europe/Berlin')
            .toFormat(format || 'dd/MM/yyyy');
    }
    static jsDateToIsoDate(date) {
        return DateTime.fromJSDate(date).setZone('Europe/Berlin').toISODate();
    }
    static formattedDateToIsoDate(formattedDate) {
        return DateTime.fromFormat(formattedDate, 'dd/MM/yyyy').toISODate();
    }
    static isValidDate(date) {
        return date ? DateTime.fromJSDate(date).isValid : false;
    }
    static isoDatesHasDiff(currentIsoDate, newIsoDate) {
        const currentDate = DateTime.fromISO(currentIsoDate);
        const nextDate = DateTime.fromISO(newIsoDate);
        return !currentDate.hasSame(nextDate, 'day') || !currentDate.hasSame(nextDate, 'month') || !currentDate.hasSame(nextDate, 'year');
    }
}

class FormHelper {
    static inputClasses(formGroup, controlName, formGlobalError) {
        const control = formGroup.get(controlName);
        if (!control) {
            throw new Error(`Not found: ${controlName}`);
        }
        if ((control.dirty || control.touched) && !formGlobalError && control.value) {
            return control.valid ? 'input-valid' : 'input-invalid';
        }
        if (formGlobalError) {
            return 'input-in-form-invalid';
        }
        // control has not been touched, so it must not have a border
        return '';
    }
}

var fr = {
    fr: {
        days: ['dimanche', 'lundi', 'mardi', 'mercredi', 'jeudi', 'vendredi', 'samedi'],
        daysShort: ['dim.', 'lun.', 'mar.', 'mer.', 'jeu.', 'ven.', 'sam.'],
        daysMin: ['dim.', 'lun.', 'mar.', 'mer.', 'jeu.', 'ven.', 'sam.'],
        months: ['janvier', 'février', 'mars', 'avril', 'mai', 'juin', 'juillet', 'août', 'septembre', 'octobre', 'novembre', 'décembre'],
        monthsShort: ['janv.', 'févr.', 'mars', 'avril', 'mai', 'juin', 'juil.', 'août', 'sept.', 'oct.', 'nov.', 'déc.'],
        today: "Aujourd'hui",
        monthsTitle: 'Mois',
        clear: 'Effacer',
        weekStart: 1,
        format: 'dd/MM/yyyy'
    }
};

var es = {
    es: {
        days: ['Domingo', 'Lunes', 'Martes', 'Miércoles', 'Jueves', 'Viernes', 'Sábado'],
        daysShort: ['Dom', 'Lun', 'Mar', 'Mié', 'Jue', 'Vie', 'Sáb'],
        daysMin: ['Do', 'Lu', 'Ma', 'Mi', 'Ju', 'Vi', 'Sa'],
        months: ['Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio', 'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre'],
        monthsShort: ['Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun', 'Jul', 'Ago', 'Sep', 'Oct', 'Nov', 'Dic'],
        today: 'Hoy',
        monthsTitle: 'Meses',
        clear: 'Borrar',
        weekStart: 1,
        format: 'dd/MM/yyyy'
    }
};

class OnlyNumberDirective {
    constructor() { }
    onInput(event) {
        const pattern = /\d/;
        const inputChar = String(event.key);
        if (!pattern.test(inputChar)) {
            event.preventDefault();
            return false;
        }
        return true;
    }
}
OnlyNumberDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: OnlyNumberDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
OnlyNumberDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.2.9", type: OnlyNumberDirective, selector: "[ngxOnlyNumber]", host: { listeners: { "keypress": "onInput($event)" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: OnlyNumberDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxOnlyNumber]'
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { onInput: [{
                type: HostListener,
                args: ['keypress', ['$event']]
            }] } });

class NgxSimpleDatepickerComponent {
    constructor() {
        this.placeholder = '';
        this.formGlobalError = false; // to handle the case in which the entire form is in error and apply a style accordingly
        this.language = 'fr';
        this.notInFuture = false;
        this.notInPast = false;
        this.displayedValue = '';
        this.hasFocus = false;
        this.disabled = false;
        this.touched = false;
        this.dateH = DateHelper;
        this.formH = FormHelper;
        this.mask = [/\d/, /\d/, '/', /\d/, /\d/, '/', /\d/, /\d/, /\d/, /\d/];
        this.autoCorrectedDatePipe = createAutoCorrectedDatePipe('dd/mm/yyyy');
        this.maskRegex = new RegExp('[0-9]{2}/[0-9]{2}/[0-9]{4}');
        Object.assign(Datepicker.locales, fr, es);
        // Set the zone to use another than French zone
        // Because => https://github.com/microsoft/TypeScript/issues/32265#issuecomment-509275445
        Settings.defaultZone = 'Europe/Berlin';
    }
    ngAfterViewInit() {
        this.createDatepicker();
    }
    ngOnDestroy() {
        if (this.datepicker) {
            this.datepicker.destroy();
        }
        try {
            // eslint-disable-next-line prefer-destructuring
            const dt = this.dpContainer.nativeElement.getElementsByTagName('input')[0];
            dt.removeEventListener('changeDate', this.onDateChange.bind(this));
        }
        catch (e) {
            console.error('Error: ', e);
        }
    }
    onModelChange(dateStr) {
        if (!dateStr) {
            if (this.value) {
                this.value = this.dateH.isoDateStringToJSDate();
                this.markAsTouched();
                this.onChange(this.value);
            }
            return;
        }
        const dateIso = this.maskRegex.test(dateStr) ? this.dateH.formattedDateToIsoDate(dateStr) : 'Invalid date';
        const currentDateIso = this.value ? this.dateH.jsDateToIsoDate(this.value) : 'Invalid date';
        if (this.dateH.isoDatesHasDiff(currentDateIso, dateIso)) {
            this.markAsTouched();
            this.value = this.dateH.isoDateStringToJSDate(dateIso);
            this.onChange(this.value);
        }
    }
    onDateChange(event) {
        if (!event.detail || !event.detail.date) {
            return;
        }
        const isoDate = this.dateH.jsDateToIsoDate(event.detail.date);
        if (!this.value || this.dateH.isoDatesHasDiff(this.dateH.jsDateToIsoDate(this.value), isoDate)) {
            const jsDate = this.dateH.isoDateStringToJSDate(isoDate);
            this.value = jsDate;
            this.displayedValue = this.valueToDisplayedValue(jsDate);
            this.onChange(jsDate);
        }
    }
    writeValue(date) {
        this.value = date;
        this.displayedValue = this.valueToDisplayedValue(date);
    }
    validate(control) {
        const { value } = control;
        if (!this.dateH.isValidDate(value)) {
            return {
                invalidDate: true
            };
        }
        return null;
    }
    openDatepicker() {
        if (this.disabled) {
            return;
        }
        if (this.value) {
            this.datepicker?.setDate(this.dateH.jsDateToFormattedDate(this.value, this.datepicker?.config.format));
        }
        else {
            this.datepicker?.setDate({ clear: true });
            this.datepicker?.update();
        }
        this.datepicker?.show();
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    onFocus(value) {
        this.hasFocus = value;
    }
    valueToDisplayedValue(value) {
        if (!value) {
            return '';
        }
        if (!this.dateH.isValidDate(value)) {
            return this.displayedValue;
        }
        const isoDate = this.dateH.jsDateToIsoDate(value);
        return this.dateH.isoDateStringToFormattedDate(isoDate);
    }
    markAsTouched() {
        if (!this.touched) {
            this.touched = true;
            this.onTouched();
        }
    }
    createDatepicker() {
        try {
            // eslint-disable-next-line prefer-destructuring
            const dt = this.dpContainer.nativeElement.getElementsByTagName('input')[0];
            dt.addEventListener('changeDate', this.onDateChange.bind(this));
            this.datepicker = new Datepicker(dt, {
                autohide: true,
                showOnClick: false,
                showOnFocus: false,
                language: this.language,
                orientation: this.verticalPosition ? `${this.verticalPosition} right` : 'auto right',
                format: 'dd/MM/yyyy',
                daysOfWeekHighlighted: [0, 6],
                todayHighlight: true,
                updateOnBlur: false,
                nextArrow: '<i class="ngx-sdp ngx-sdp-angle-right"></i>',
                prevArrow: '<i class="ngx-sdp ngx-sdp-angle-left"></i>',
                container: this.dpContainer.nativeElement,
                minDate: this.notInPast ? new Date() : undefined,
                maxDate: this.notInFuture ? new Date() : undefined
            });
        }
        catch (e) {
            console.error('Error: ', e);
        }
    }
}
NgxSimpleDatepickerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxSimpleDatepickerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
NgxSimpleDatepickerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.9", type: NgxSimpleDatepickerComponent, selector: "ngx-simple-datepicker", inputs: { form: "form", inputKey: "inputKey", placeholder: "placeholder", formGlobalError: "formGlobalError", language: "language", verticalPosition: "verticalPosition", notInFuture: "notInFuture", notInPast: "notInPast" }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: NgxSimpleDatepickerComponent,
            multi: true
        },
        {
            provide: NG_VALIDATORS,
            multi: true,
            useExisting: NgxSimpleDatepickerComponent
        }
    ], viewQueries: [{ propertyName: "dpContainer", first: true, predicate: ["dpContainer"], descendants: true }], ngImport: i0, template: "<div class=\"ng-simple-datepicker\" [class]=\"formH.inputClasses(form, inputKey, formGlobalError)\" [class.focus]=\"hasFocus\" [class.disabled]=\"disabled\">\n  <input\n    [id]=\"inputKey\"\n    class=\"datepicker-input-text\"\n    type=\"text\"\n    [textMask]=\"{ mask: mask, keepCharPositions: true, guide: true, pipe: autoCorrectedDatePipe }\"\n    [(ngModel)]=\"displayedValue\"\n    (ngModelChange)=\"onModelChange($event)\"\n    [placeholder]=\"placeholder\"\n    (focusin)=\"onFocus(true)\"\n    (focusout)=\"onFocus(false)\"\n    [disabled]=\"disabled\"\n    ngxOnlyNumber\n  />\n  <div class=\"datepicker-container\" #dpContainer>\n    <input id=\"datepicker\" type=\"text\" name=\"datepicker\" class=\"datepicker-input\" readonly />\n  </div>\n  <div (click)=\"openDatepicker()\" class=\"datepicker-open-button\">\n    <i class=\"ngx-sdp ngx-sdp-calendar\"></i>\n  </div>\n</div>\n", dependencies: [{ kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2.MaskedInputDirective, selector: "[textMask]", inputs: ["textMask"], exportAs: ["textMask"] }, { kind: "directive", type: OnlyNumberDirective, selector: "[ngxOnlyNumber]" }], encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxSimpleDatepickerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-simple-datepicker', providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: NgxSimpleDatepickerComponent,
                            multi: true
                        },
                        {
                            provide: NG_VALIDATORS,
                            multi: true,
                            useExisting: NgxSimpleDatepickerComponent
                        }
                    ], encapsulation: ViewEncapsulation.None, template: "<div class=\"ng-simple-datepicker\" [class]=\"formH.inputClasses(form, inputKey, formGlobalError)\" [class.focus]=\"hasFocus\" [class.disabled]=\"disabled\">\n  <input\n    [id]=\"inputKey\"\n    class=\"datepicker-input-text\"\n    type=\"text\"\n    [textMask]=\"{ mask: mask, keepCharPositions: true, guide: true, pipe: autoCorrectedDatePipe }\"\n    [(ngModel)]=\"displayedValue\"\n    (ngModelChange)=\"onModelChange($event)\"\n    [placeholder]=\"placeholder\"\n    (focusin)=\"onFocus(true)\"\n    (focusout)=\"onFocus(false)\"\n    [disabled]=\"disabled\"\n    ngxOnlyNumber\n  />\n  <div class=\"datepicker-container\" #dpContainer>\n    <input id=\"datepicker\" type=\"text\" name=\"datepicker\" class=\"datepicker-input\" readonly />\n  </div>\n  <div (click)=\"openDatepicker()\" class=\"datepicker-open-button\">\n    <i class=\"ngx-sdp ngx-sdp-calendar\"></i>\n  </div>\n</div>\n" }]
        }], ctorParameters: function () { return []; }, propDecorators: { dpContainer: [{
                type: ViewChild,
                args: ['dpContainer']
            }], form: [{
                type: Input
            }], inputKey: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], formGlobalError: [{
                type: Input
            }], language: [{
                type: Input
            }], verticalPosition: [{
                type: Input
            }], notInFuture: [{
                type: Input
            }], notInPast: [{
                type: Input
            }] } });

class NgxSimpleDatepickerModule {
}
NgxSimpleDatepickerModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxSimpleDatepickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxSimpleDatepickerModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.9", ngImport: i0, type: NgxSimpleDatepickerModule, declarations: [NgxSimpleDatepickerComponent, OnlyNumberDirective], imports: [CommonModule, ReactiveFormsModule, FormsModule, TextMaskModule], exports: [NgxSimpleDatepickerComponent] });
NgxSimpleDatepickerModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxSimpleDatepickerModule, providers: [DateHelper, FormHelper], imports: [CommonModule, ReactiveFormsModule, FormsModule, TextMaskModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxSimpleDatepickerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [NgxSimpleDatepickerComponent, OnlyNumberDirective],
                    imports: [CommonModule, ReactiveFormsModule, FormsModule, TextMaskModule],
                    exports: [NgxSimpleDatepickerComponent],
                    providers: [DateHelper, FormHelper]
                }]
        }] });

/*
 * Public API Surface of ngx-simple-datepicker
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxSimpleDatepickerComponent, NgxSimpleDatepickerModule };
//# sourceMappingURL=nolanroose-ngx-simple-datepicker.mjs.map
